==> mono_1.1.13.6.orig.tar.gz: mono-1.1.13.6/mcs/class/System.Web/System.Web.UI.WebControls.Adapters/WebControlAdapter.cs <==
//
// System.Web.UI.WebControls.Adapters.WebControlAdapter
//
// Author:
//	Chris Toshok  <toshok@ximian.com>
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;
using System.Web.UI.Adapters;

namespace System.Web.UI.WebControls.Adapters
{
	public class WebControlAdapter : ControlAdapter
	{
		public WebControlAdapter()
		{
		}

		protected internal override void Render (HtmlTextWriter writer)
		{
			RenderBeginTag (writer);
			RenderContents (writer);
			RenderEndTag (writer);
		}

		protected virtual void RenderBeginTag (HtmlTextWriter writer)
		{
			control.RenderBeginTag (writer);
		}

		protected virtual void RenderContents(HtmlTextWriter writer)
		{
			control.Render (writer);
		}

		protected virtual void RenderEndTag(HtmlTextWriter writer)
		{
			control.RenderEndTag (writer);
		}

		protected new WebControl Control
		{
			get {
				return control;
			}
		}

		protected bool IsEnabled
		{
			get {
				return control.IsEnabled;
			}
		}

		WebControl control;
	}
}

#endif

==> mono_4.2.1.102+dfsg2.orig.tar.gz: mono-4.2.1+dfsg2/mcs/class/System.Web/System.Web.UI.WebControls.Adapters/WebControlAdapter.cs <==
//
// System.Web.UI.WebControls.Adapters.WebControlAdapter
//
// Author:
//	Chris Toshok  <toshok@ximian.com>
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;
using System.Web.UI.Adapters;

namespace System.Web.UI.WebControls.Adapters
{
	public class WebControlAdapter : ControlAdapter
	{
		public WebControlAdapter ()
		{
		}
		
		internal WebControlAdapter (WebControl wc) : base (wc)
		{
		}

		protected internal override void Render (HtmlTextWriter writer)
		{
			RenderBeginTag (writer);
			RenderContents (writer);
			RenderEndTag (writer);
		}

		protected virtual void RenderBeginTag (HtmlTextWriter writer)
		{
			Control.RenderBeginTag (writer);
		}

		protected virtual void RenderContents(HtmlTextWriter writer)
		{
			Control.RenderContents (writer);
		}

		protected virtual void RenderEndTag(HtmlTextWriter writer)
		{
			Control.RenderEndTag (writer);
		}

		protected new WebControl Control
		{
			get {
				return (WebControl)control;
			}
		}

		protected bool IsEnabled
		{
			get {
				return Control.IsEnabled;
			}
		}
	}
}
